#
# spec file for package perl-YAML-PP
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name YAML-PP
Name:           perl-YAML-PP
Version:        0.035
Release:        bp155.1.5
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        YAML 1.2 Processor
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TI/TINITA/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Load)
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::More) >= 0.98
BuildRequires:  perl(Test::Warn)
Requires:       perl(Module::Load)
%{perl_requires}

%description
YAML::PP is a modular YAML processor.

It aims to support 'YAML 1.2' and 'YAML 1.1'. See https://yaml.org/. Some
(rare) syntax elements are not yet supported and documented below.

YAML is a serialization language. The YAML input is called "YAML Stream". A
stream consists of one or more "Documents", separated by a line with a
document start marker '---'. A document optionally ends with the document
end marker '...'.

This allows one to process continuous streams additionally to a fixed input
file or string.

The YAML::PP frontend will currently load all documents, and return only
the first if called with scalar context.

The YAML backend is implemented in a modular way that allows one to add
custom handling of YAML tags, perl objects and data types. The inner API is
not yet stable. Suggestions welcome.

You can check out all current parse and load results from the
yaml-test-suite here: https://perlpunk.github.io/YAML-PP-p5/test-suite.html

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md examples Makefile.dev README.md
%license LICENSE

%changelog
* Sat Oct  1 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.035
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.035 2022-09-30 21:16:16+02:00
  - Fix parsing alias as mapping key
  - Support emitting folded block scalars. Now any input should
    be able to output as a folded block scalar correctly. Preserving
    scalar styles will now also preserve those
* Fri Jul  1 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.034
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.034 2022-06-30 10:31:56+02:00
  - Fix parsing empty folded block scalars with trailing linebreaks
  - Fix error handling (remaining tokens on invalid input)
  - Support experimental v5.36 booleans
  - Allow to specify multiple boolean classes (issue #37)
* Tue Jun 28 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.033
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.033 2022-06-27 16:31:32+02:00
  - Fix add_mapping_resolver + on_create (tie existing data)
* Wed Mar  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.032
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.032 2022-03-08 19:02:00+01:00
  - Add missing '~' to allowed chars in tags
  - Restructure directive parsing a bit
  - Support YAML::PP::Ref in yamlpp-* utility scripts
  - Add -P to yaml-load-dump --preserve
  - Add --dump option to yamlpp-parse-emit
  - yamlpp-load-dump -D JSON::PP: don't output space before colon
  - Add export tags to YAML::PP::Common
  - Update yaml-test-suite to 2022-01-17
* Sun Dec 26 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.031
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.031 2021-12-25 23:43:19+01:00
  - Fix several rare test cases:
  - Support literal escaped tabs
  - Allow only one digit for block scalar indent indicator
  - Allow comments at the end of directives
  - Match word boundary after '%%YAML'
  - Allow tabs and multiple spaces between directive elements
  - Forbid lines starting with tabs in block mode
  - After tabs no further indentation elements allowed
* Mon Nov  8 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.030
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.030 2021-11-07 21:57:28+01:00
  - preserve: Keep existing data (issue #44)
  - Forbid directive without directive end marker
  - Support explicit empty key/value pairs in flow mappings
  - Enforce EOL after end of flow context
  - Forbid multiple question marks in flow mappings
* Mon Oct 25 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.029
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.029 2021-10-25 00:02:53+02:00
  - Fix basic implicit mappings in flow sequences, e.g. [a, b: c, d]
  0.028 2021-10-21 22:00:36+02:00
  - Fix empty values with properties in flow mappings and sequences
    (`[ &foo , bar]`, `{ &foo , k: v }`)
  - Fix: Allow comment lines with tabs in flow
  - Fix: parsing of explicit block indenting (issue #46)
  - Automatically tie new hashes inside tied hashes (issue #44)
  - yamlpp-load-dump: Add options --dump-module and --include*
  - docs: Add mising constants (issue #45)
* Sat Apr 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.027
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.027 2021-04-09 11:13:28+02:00
  - Forbid duplicate keys by default like announced in 0.026
  - Add possibility to preserve alias names (see 'preserve' option)
  - Highlighter: Add option to expand tabs in ansi color mode
  - yamlpp-events: Add option --module
  - Improve error message when trying to load an undefined alias
  - Fix a test for perl 5.8.8
* Fri Sep 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.026
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.026 2020-09-11 00:39:09+02:00
  - Add option 'duplicate_keys'. The default allows it for now and will
    change to forbid in the next release.
* Mon Sep  7 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.025
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.025 2020-09-06 22:14:07+02:00
  - Emitter: Fix indentation issues for non-default indents
  - Emitter: Add option 'width' for maximum columns
  - Improve error message for unhandled reftypes
* Tue Aug 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.024
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.024 2020-08-17 12:07:01+02:00
  - Parser: fix flow mappings on one line
  - Improve utility tools yamlpp-load(-dump) (add new options --merge,
  - -perl and --module) #35
  - Minor improvements to emitter scalar style output
  - Emitter supports flow style
  - Support for preserving flow style in Loader/Dumper
  - Create preserved nodes from scratch with preserved_* methods
  - Minor fixes for the Perl schema and globs
  - Update testsuite to data-2020-08-01
* Fri Jul 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.023
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.023 2020-07-09 22:09:50+02:00
  - Support loading and dumping typeglobs. Issue #15
  - Dumper: Don't use aliases for JSON::PP/boolean.pm booleans, because they
    alwas use the same reference. Issue #32
  - Fix float comparison in test. Issue #33
  - Make aliases in custom tags work
  - YAML::PP::Highlight: colorize mapping keys
* Tue May  5 2020 Tina Müller <timueller+perl@suse.de>
  updated to 0.022
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.022 2020-05-04 17:40:36+02:00
  - Emitter: Also quote if string starts with '...'
  - Emitter: Fix bug when emitting complex keys
  - Preserve also quoting style of hash keys
  - Schema: Fix YAML 1.1 integers (no keading zeros)
  - Scripts: Rename yamlpp5- to yamlpp- and symlink
  - Scripts: Add options to yamlpp-load-dump
  - Tests: Support reporting flow style in testsuite event output
  - Tests: Restructure schema tests and outsource test data
  - Events: Make version_directive compatible to libyaml
  - Docs: Restructure
* Fri Feb 28 2020 <timueller+perl@suse.de>
- updated to 0.021
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.021 2020-02-27 19:04:58+01:00
  - Add option 'preserve' for preserving hash key order and quoting
    style when loading and dumping
* Tue Feb 18 2020 <timueller+perl@suse.de>
- updated to 0.020
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.020 2020-02-17 15:35:44+01:00
  - Change default schema from JSON to Core (this change was supposed
    to go in 0.019 but wasn't completely done)
  - Add option version_directive (print %%YAML 1.2)
  - Add option yaml_version
  - Add support for detecting the right schema depending on the
    YAML version directive
  - Support both %%YAML and %%TAG directive for a document
  - Improve emitter (output footer ... after open-ended block scalars)
  - Improve emitter (quote strings starting with `---` to reduce ambiguity
    for the reader)
* Fri Feb 14 2020 <timueller+perl@suse.de>
- updated to 0.019
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.019 2020-02-13 16:06:56+01:00
  - Important (and possibly breaking) changes:
  - Change default schema from JSON to Core.
    Reason: This is the recommended Schema for YAML 1.2, and what people
    would expect to be the default.
  - load* in scalar context returns first document.
    Reason: I think this is the most reasonable behaviour, and it
    will continue to work the same if you later add documents to a file.
  - Empty nodes in YAML 1.2 JSON Schema resolve to '' by default like
    before, but now it can be configured
  - Fix some control character escaping and encoding issues (issue#16, issue#17)
    YAML::PP will now just assume all input data are unicode characters
    and won't do an explicit utf8::upgrade
  - Fix Core schema resolver for inf: add +.inf, +.Inf, +.INF
  - Improve emitter regarding empty lists/hashes (no newline before []/{})
  - Spelling and grammar fixes (PR#23 @gregoa)
  - Fix YAML::PP::Grammar pod (PR#22 @gregoa)
  - Fix yamlpp5-load-dump
  - Fix error tokens output
  - Update yaml-test-suite to data-2020-02-11
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.018
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.018 2019-07-06 19:40:10+02:00
  - Turn scalar style constants into numbers
  - Deprecate YAML_QUOTED_SCALAR_STYLE
* Sun Jun 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.017
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.017 2019-06-29 14:34:17+02:00
  - Add Include plugin
  - Allow to only bless specific classes for Perl Schema
  - YAML::PP accepts existing schema in constructor
  - subschema can be an object
  - Switch the order of 'equals' and regex tag resolvers
* Tue May 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.016
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  Revision history for Perl module YAML::PP
  0.016 2019-05-20 12:37:01+02:00
  - Change load methods to return the last document in scalar context for
    compatibility with other YAML loaders
  - Fix Lexer/Emitter (allowing/forbidding special characters in plain scalars)
  - Custom representer must fill $node->{data}
  - Dump: uptf8::upgrade input value (so it can store binary data)
* Wed May 15 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.015
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.015 2019-05-14 21:00:59+02:00
  - Support Mac 
 and Win
  line endings
  - Add options header and footer
  - Add support for merge keys
* Wed May  8 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.014
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.014 2019-05-07 21:46:56+02:00
  - Change tagtype option in Perl Schema (e.g. tag=!perl+!!perl)
  - Change on_data handler to pass a reference
* Wed May  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.013
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.013 2019-04-30 16:02:52+02:00
  - Add option "indent" for dumping
  - Support both !perl/ and !!perl/ tags
  - Change default schema from Core to JSON
  - Add YAML::PP::Schema::Binary for representing binary data
* Mon Apr 15 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.012
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.012 2019-04-14 14:02:36+02:00
  - Fix bug in emitter (strings starting with %% must be quoted)
  - Implement loading of schema classes not prefixed with YAML::PP::Schema
    (PR#8 @pplu)
  - Implement loading of perl objects
  - Fix line number of multiline tokens
  - Refactor parser/lexer. All tokens (except indentation) are now
    parsed by the grammar.
  - Change arguments of resolver callback
  - Add a catchall resolver for scalars
* Sat Mar 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.011
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.011 2019-03-23 12:03:12+01:00
  - Add YAML::PP::Common; use constants for YAML styles
  - Add YAML::PP::Schema::Perl - Dump perl objects, coderefs etc.
  - Add YAML::PP::Schema::Tie::IxHash - keep order of hashes
  - Add YAML::PP::Schema::YAML1_1
  - Add class_isa representer (PR#7 @pplu)
  - Add exceptions in tests for broken inf
  - Refactor schema testing
  - Fix indent bugs in emitter (aliases, empty lists/mappings)
  - Fix bug in emitter for values starting with '? ' or '- '
  - Add missing resolvers to Core and YAML1_1 Schema
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.010
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.010 2018-11-02 12:53:41+01:00
  - Fix regex for start of plain scalars
  - Large refactoring of lexer/parser.
  - Adjacent flow mapping values are now supported (JSON compat:
    `{"foo":23}`)
  - Empty flow mapping values are now supported
  - Fix nested flow collections
  0.009 2018-09-30 14:10:15+02:00
  - Fix yamlpp5-highlight bug from v0.008
  - load_file(), LoadFile(), dump_file() and DumpFile() can take filehandles
* Tue Sep 25 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.008
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.008 2018-09-24 21:49:42+02:00
  - Support perl 5.8
  - Fix bug in folded block scalar parsing
  - Support multiple document end markers without content
  - Allow tabs at the beginning of line for flow nodes
  - Optimize reading input with many lines
  - Some internal changes
  - Refactor test suite
  - Add YAML::PP::Highlight::Dump()
* Thu Jun 21 2018 coolo@suse.com
- updated to 0.007
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.007 2018-06-20 21:36:26+02:00
  - Support .inf/.nan
  - Always output decimal point when dumping floats
  - YAML directive needs space
  - Improve emitter
  - Output multiline strings as literal block scalars
  - Fix regex for integers in Core Schema
  - Fix dumping of dualvars
  - Fix emitting of empty strings
  - Improve emitter scalar styles
  - Allow zero indented sequences for complex mapping keys/values
  - Fix parsing empty quoted strings
* Mon Apr  2 2018 coolo@suse.com
- updated to 0.006
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.006 2018-04-01 22:59:31+02:00
  - Support YAML Failsafe, JSON and Core Schema
  - Add dump_file, DumpFile
  - Add YAML::PP::Writer
  - Add YAML::PP::Representer
  - Detect cyclic references when loading
  - perl boolean false is now the empty string instead of 0
  - Add column numbers to error messages
  - Fixed various bugs in Emitter
  - Can now emit empty collections like [], {}
* Fri Nov 24 2017 coolo@suse.com
- updated to 0.005
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.005 2017-11-23 17:09:55+01:00
  - Support reading files
  - Replace load() with load_string(), dump() with dump_string()
  - Support legacy interface functions Load, LoadFile, Dump
  - ... and --- are now correctly invalid in quoted scalars
  - Improve block scalar handling, passing two more tests
  - Improve multiline plain handling, passing another test
  - Partial implementation of flow style collections
  - Allow unicode in alias/anchor names
  - Document header at the end is now recognized
  - Support all valid escapes in double quotes
  - ...and forbid invalid ones
  - Multiline quoted strings must be indented
  - Forbid sequence or mapping as a mapping value on the same line
  - Forbit sequence after an anchor/tag on the same line
* Sun Oct  8 2017 coolo@suse.com
- initial package 0.004
  * created by cpanspec 1.78.08
